window.Gleam.initSearch([{"doc":"gleam_regexp","title":"gleam_regexp","content":"# Regexp\n\nRegular expressions in Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/gleam_regexp)](https://hex.pm/packages/gleam_regexp)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_regexp/)\n\n```sh\ngleam add gleam_regexp@1\n```\n```gleam\nimport gleam/regexp\n\npub fn main() {\n  let assert Ok(re) = regexp.from_string(&quot;[0-9]&quot;)\n\n  regexp.check(re, &quot;abc123&quot;)\n  // -&gt; True\n\n  regexp.check(re, &quot;abcxyz&quot;)\n  // -&gt; False\n}\n```\n\nThis package uses the regular expression engine of the underlying platform.\nRegular expressions in Erlang and JavaScript largely share the same syntax, but\nthere are some differences and have different performance characteristics. Be\nsure to thoroughly test your code on all platforms that you support when using\nthis library.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleam_regexp&gt;.\n","url":"index.html"},{"doc":"gleam/regexp","title":"CompileError","content":"pub type CompileError {\n  CompileError(error: String, byte_index: Int)\n}\n When a regular expression fails to compile:\n\nCompileError(error: String, byte_index: Int)\n\nerror\n&lt;p&gt;The problem encountered that caused the compilation to fail&lt;/p&gt;\n\nbyte_index\n&lt;p&gt;The byte index into the string to where the problem was found\nThis value may not be correct in JavaScript environments.&lt;/p&gt;\n\nSynonyms:\ngleam/regexp.CompileError\ngleam/regexp CompileError","url":"gleam/regexp.html#CompileError"},{"doc":"gleam/regexp","title":"Match","content":"pub type Match {\n  Match(content: String, submatches: List(Option(String)))\n}\n The details about a particular match:\n\nMatch(content: String, submatches: List(Option(String)))\n\ncontent\n&lt;p&gt;The full string of the match.&lt;/p&gt;\n\nsubmatches\n&lt;p&gt;A &lt;code&gt;Regexp&lt;/code&gt; can have subpatterns, sup-parts that are in parentheses.&lt;/p&gt;\n\nSynonyms:\ngleam/regexp.Match\ngleam/regexp Match","url":"gleam/regexp.html#Match"},{"doc":"gleam/regexp","title":"Options","content":"pub type Options {\n  Options(case_insensitive: Bool, multi_line: Bool)\n}\n\nOptions(case_insensitive: Bool, multi_line: Bool)\n\n\nSynonyms:\ngleam/regexp.Options\ngleam/regexp Options","url":"gleam/regexp.html#Options"},{"doc":"gleam/regexp","title":"Regexp","content":"pub type Regexp\n\n\nSynonyms:\ngleam/regexp.Regexp\ngleam/regexp Regexp","url":"gleam/regexp.html#Regexp"},{"doc":"gleam/regexp","title":"check","content":"pub fn check(with regexp: Regexp, content string: String) -&gt; Bool\n Returns a boolean indicating whether there was a match or not.\n\n ## Examples\n\n \n let assert Ok(re) = from_string(&quot;^f.o.?&quot;)\n check(with: re, content: &quot;foo&quot;)\n // -&gt; True\n \n\n \n check(with: re, content: &quot;boo&quot;)\n // -&gt; False\n \n\nSynonyms:\ngleam/regexp.check\ngleam/regexp check","url":"gleam/regexp.html#check"},{"doc":"gleam/regexp","title":"compile","content":"pub fn compile(\n  pattern: String,\n  with options: Options,\n) -&gt; Result(Regexp, CompileError)\n Creates a `Regexp` with some additional options.\n\n ## Examples\n\n \n let options = Options(case_insensitive: False, multi_line: True)\n let assert Ok(re) = compile(&quot;^[0-9]&quot;, with: options)\n check(re, &quot;abc\\n123&quot;)\n // -&gt; True\n \n\n \n let options = Options(case_insensitive: True, multi_line: False)\n let assert Ok(re) = compile(&quot;[A-Z]&quot;, with: options)\n check(re, &quot;abc123&quot;)\n // -&gt; True\n \n\nSynonyms:\ngleam/regexp.compile\ngleam/regexp compile","url":"gleam/regexp.html#compile"},{"doc":"gleam/regexp","title":"from_string","content":"pub fn from_string(\n  pattern: String,\n) -&gt; Result(Regexp, CompileError)\n Creates a new `Regexp`.\n\n ## Examples\n\n \n let assert Ok(re) = from_string(&quot;[0-9]&quot;)\n check(re, &quot;abc123&quot;)\n // -&gt; True\n \n\n \n check(re, &quot;abcxyz&quot;)\n // -&gt; False\n \n\n \n from_string(&quot;[0-9&quot;)\n // -&gt; Error(CompileError(\n //   error: &quot;missing terminating ] for character class&quot;,\n //   byte_index: 4\n // ))\n \n\nSynonyms:\ngleam/regexp.from_string\ngleam/regexp from_string","url":"gleam/regexp.html#from_string"},{"doc":"gleam/regexp","title":"replace","content":"pub fn replace(\n  each pattern: Regexp,\n  in string: String,\n  with substitute: String,\n) -&gt; String\n Creates a new `String` by replacing all substrings that match the regular\n expression.\n\n ## Examples\n\n \n let assert Ok(re) = regexp.from_string(&quot;^https://&quot;)\n replace(each: re, in: &quot;https://example.com&quot;, with: &quot;www.&quot;)\n // -&gt; &quot;www.example.com&quot;\n \n\n \n let assert Ok(re) = regexp.from_string(&quot;[, +-]&quot;)\n replace(each: re, in: &quot;a,b-c d+e&quot;, with: &quot;/&quot;)\n // -&gt; &quot;a/b/c/d/e&quot;\n \nSynonyms:\ngleam/regexp.replace\ngleam/regexp replace","url":"gleam/regexp.html#replace"},{"doc":"gleam/regexp","title":"scan","content":"pub fn scan(\n  with regexp: Regexp,\n  content string: String,\n) -&gt; List(Match)\n Collects all matches of the regular expression.\n\n ## Examples\n\n \n let assert Ok(re) = from_string(&quot;[oi]n a (\\\\w+)&quot;)\n scan(with: re, content: &quot;I am on a boat in a lake.&quot;)\n // -&gt; [\n //   Match(content: &quot;on a boat&quot;, submatches: [Some(&quot;boat&quot;)]),\n //   Match(content: &quot;in a lake&quot;, submatches: [Some(&quot;lake&quot;)]),\n // ]\n \n\n \n let assert Ok(re) = regexp.from_string(&quot;([+|\\\\-])?(\\\\d+)(\\\\w+)?&quot;)\n scan(with: re, content: &quot;-36&quot;)\n // -&gt; [\n //   Match(content: &quot;-36&quot;, submatches: [Some(&quot;-&quot;), Some(&quot;36&quot;)])\n // ]\n\n scan(with: re, content: &quot;36&quot;)\n // -&gt; [\n //   Match(content: &quot;36&quot;, submatches: [None, Some(&quot;36&quot;)])\n // ]\n \n\n \n let assert Ok(re) =\n   regexp.from_string(&quot;var\\\\s*(\\\\w+)\\\\s*(int|string)?\\\\s*=\\\\s*(.*)&quot;)\n scan(with: re, content: &quot;var age = 32&quot;)\n // -&gt; [\n //   Match(\n //     content: &quot;var age = 32&quot;,\n //     submatches: [Some(&quot;age&quot;), None, Some(&quot;32&quot;)],\n //   ),\n // ]\n \n\n \n let assert Ok(re) = regexp.from_string(&quot;let (\\\\w+) = (\\\\w+)&quot;)\n scan(with: re, content: &quot;let age = 32&quot;)\n // -&gt; [\n //   Match(\n //     content: &quot;let age = 32&quot;,\n //     submatches: [Some(&quot;age&quot;), Some(&quot;32&quot;)],\n //   ),\n // ]\n\n scan(with: re, content: &quot;const age = 32&quot;)\n // -&gt; []\n \n\nSynonyms:\ngleam/regexp.scan\ngleam/regexp scan","url":"gleam/regexp.html#scan"},{"doc":"gleam/regexp","title":"split","content":"pub fn split(\n  with regexp: Regexp,\n  content string: String,\n) -&gt; List(String)\n Splits a string.\n\n ## Examples\n\n \n let assert Ok(re) = from_string(&quot; *, *&quot;)\n split(with: re, content: &quot;foo,32, 4, 9  ,0&quot;)\n // -&gt; [&quot;foo&quot;, &quot;32&quot;, &quot;4&quot;, &quot;9&quot;, &quot;0&quot;]\n \n\nSynonyms:\ngleam/regexp.split\ngleam/regexp split","url":"gleam/regexp.html#split"},{"doc":"gleam/regexp","title":"gleam/regexp","content":" This package uses the regular expression engine of the underlying platform.\n Regular expressions in Erlang and JavaScript largely share the same syntax, but\n there are some differences and have different performance characteristics. Be\n sure to thoroughly test your code on all platforms that you support when using\n this library.","url":"gleam/regexp.html"}]);